@@ -1,18 +1,12 @@
 // Copyright 2020 Google LLC
 //
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//    https://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
+// https://www.apache.org/licenses/LICENSE-2.0> or the MIT license
+// <LICENSE-MIT or https://opensource.org/licenses/MIT>, at your
+// option. This file may not be copied, modified, or distributed
+// except according to those terms.
 
-use std::collections::HashSet;
+use std::{borrow::Cow, collections::HashSet};
 
 use proc_macro2::Span;
 use quote::ToTokens;
@@ -353,7 +347,7 @@ impl IncludeCppConfig {
         if self.exclude_utilities {
             Vec::new()
         } else {
-            vec![self.get_makestring_name()]
+            vec![self.get_makestring_name().to_string()]
         }
     }
 
@@ -390,14 +384,18 @@ impl IncludeCppConfig {
         self.blocklist.iter()
     }
 
-    pub fn get_makestring_name(&self) -> String {
-        format!(
-            "autocxx_make_string_{}",
-            self.mod_name
-                .as_ref()
-                .map(|i| i.to_string())
-                .unwrap_or_else(|| "default".into())
-        )
+    /// In case there are multiple sets of ffi mods in a single binary,
+    /// endeavor to return a name which can be used to make symbols
+    /// unique.
+    pub fn uniquify_name_per_mod<'a>(&self, name: &'a str) -> Cow<'a, str> {
+        match self.mod_name.as_ref() {
+            None => Cow::Borrowed(name),
+            Some(md) => Cow::Owned(format!("{}_{}", name, md)),
+        }
+    }
+
+    pub fn get_makestring_name(&self) -> Cow<str> {
+        self.uniquify_name_per_mod("autocxx_make_string")
     }
 
     pub fn is_rust_type(&self, id: &Ident) -> bool {
